;
; AC, le 02/05/2005
;
; This function gives an interactive way to select
; ONE and only one bolometer in a bolo list
;
; The Input is a bolo list (struture list)
; The Output is a single bolo element (structure)
; If no Input is provide, the dafault file is read.
;
function LIST_BOLO_SELECT, bolo_list=bolo_list, $
                           help=help, test=test, verbose=verbose
;
mess=AC_SETMESSAGES('LIST_BOLO_SELECT')
;
if KEYWORD_SET(help) then begin
    print, 'pro LIST_BOLO_SELECT, bolo_list=bolo_list, $'
    print, '                      help=help, test=test, verbose=verbose'
    return, -1
endif
;
; If no bolo_list is provided, then we read the default file
; containing a list of the bolo and their parameters
;
if (N_ELEMENTS(bolo_list) LT 1) then begin
    print, mess.warning+'No [bolo_list] provide, Default bolo file read'
    bolo_list=LIST_BOLO_READFILE(/verbose)
endif
;
; From this point, we have three cases: 0, 1, or N bolo
;
if (N_ELEMENTS(bolo_list) EQ 0) then begin
    print, mess.fatal+'No Bolo available'
    return, -1
endif
if (N_ELEMENTS(bolo_list) EQ 1) then begin
    print, mess.warning+'Only one available bolometer'
    bolo=bolo_list
endif
;
; From this point we more than One bolo
; We can interactively select ONE in a list
;
if (N_ELEMENTS(bolo_list) GT 1) then begin
    texte=['Bolo names', bolo_list.name, 'quit']
    reponse=AC_WMENU(texte,title=0,init=1)
    if (reponse EQ (N_ELEMENTS(texte)-1)) then begin
        return, -1
    endif else begin
        bolo_name=bolo_list(reponse-1).name
    endelse
    ;;
    bolo=LIST_BOLO_EXTRACT(bolo_list, name=bolo_name,/verbose)
    ;;
    print, mess.info, 'selected bolo is: ', bolo.name
endif
;
if KEYWORD_SET(verbose) then begin
    print, mess.info, 'bolo parameters are: ', bolo
    HELP,/ Struct, bolo
endif
;
if KEYWORD_SET(test) then STOP
;
return, bolo
;
end
